==> opencart_v1.2.6.zip: opencart_v1.2.6/upload/admin/language/english/english.php <==
<?php
// Locale
$_['code']              = 'en';
$_['direction']         = 'ltr';
$_['date_format_short'] = 'd/m/Y';
$_['date_format_long']  = 'l dS F Y';
$_['time_format']       = 'h:i:s A';
$_['decimal_point']     = '.';
$_['thousand_point']    = ',';

// Text
$_['text_time']               = 'Page created in %s seconds';
$_['text_yes']                = 'Yes';
$_['text_no']                 = 'No';
$_['text_plus']               = '+';
$_['text_minus']              = '-';
$_['text_enabled']            = 'Enabled';
$_['text_disabled']           = 'Disabled';
$_['text_none']               = ' --- None --- ';
$_['text_all_zones']          = 'All Zones';
$_['text_default']            = ' <b>(Default)</b>';
$_['text_close']              = 'Close';
$_['text_pagination']         = 'Showing %s to %s of %s (%s Pages)';
$_['text_no_results']         = 'No results!';
$_['text_separator']          = ' &gt; ';
$_['text_edit']               = 'Edit';
$_['text_view']               = 'View';
$_['text_home']               = 'Home';

// Button
$_['button_insert']           = 'Insert';
$_['button_delete']           = 'Delete';
$_['button_save']             = 'Save';
$_['button_cancel']           = 'Cancel';
$_['button_close']            = 'Close';
$_['button_filter']           = 'Filter';
$_['button_send']             = 'Send';
$_['button_back']             = 'Back';
$_['button_remove']           = 'Remove';
$_['button_import']           = 'Import';
$_['button_export']           = 'Export';
$_['button_invoice']          = 'Invoice';
$_['button_add_option']       = 'Add Option';
$_['button_add_option_value'] = 'Add Option Value';
$_['button_add_discount']     = 'Add Discount';
$_['button_add_special']      = 'Add Special Price';
$_['button_add_image']        = 'Add Image';
$_['button_add_geo_zone']     = 'Add Geo Zone';
$_['button_add_rate']         = 'Add Tax Rate';

// Tab
$_['tab_admin']               = 'Admin';
$_['tab_cache']               = 'Cache';
$_['tab_data']                = 'Data';
$_['tab_discount']            = 'Discount';
$_['tab_general']             = 'General';
$_['tab_image']               = 'Image';
$_['tab_option']              = 'Option';
$_['tab_shop']                = 'Shop';
$_['tab_local']               = 'Local';
$_['tab_stats']               = 'Statistics';
$_['tab_order']               = 'Orders';
$_['tab_customer']            = 'Customers';

// Error
$_['error_upload_1']          = 'Warning: The uploaded file exceeds the upload_max_filesize directive in php.ini!';
$_['error_upload_2']          = 'Warning: The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form!';
$_['error_upload_3']          = 'Warning: The uploaded file was only partially uploaded!';
$_['error_upload_4']          = 'Warning: No file was uploaded!';
$_['error_upload_6']          = 'Warning: Missing a temporary folder!';
$_['error_upload_7']          = 'Warning: Failed to write file to disk!';
$_['error_upload_8']          = 'Warning: File upload stopped by extension!';
$_['error_upload_999']        = 'Warning: No error code avaiable!';
?>

==> opencart_v1.3.0.zip: opencart_v1.3.0/upload/admin/language/english/english.php <==
<?php
// Locale
$_['code']                    = 'en';
$_['direction']               = 'ltr';
$_['date_format_short']       = 'd/m/Y';
$_['date_format_long']        = 'l dS F Y';
$_['time_format']             = 'h:i:s A';
$_['decimal_point']           = '.';
$_['thousand_point']          = ',';

// Text
$_['text_time']               = 'Page created in %s seconds';
$_['text_yes']                = 'Yes';
$_['text_no']                 = 'No';
$_['text_plus']               = '+';
$_['text_minus']              = '-';
$_['text_enabled']            = 'Enabled';
$_['text_disabled']           = 'Disabled';
$_['text_none']               = ' --- None --- ';
$_['text_all_zones']          = 'All Zones';
$_['text_default']            = ' <b>(Default)</b>';
$_['text_close']              = 'Close';
$_['text_pagination']         = 'Showing %s to %s of %s (%s Pages)';
$_['text_no_results']         = 'No results!';
$_['text_separator']          = ' &gt; ';
$_['text_edit']               = 'Edit';
$_['text_view']               = 'View';
$_['text_home']               = 'Home';

// Button
$_['button_insert']           = 'Insert';
$_['button_delete']           = 'Delete';
$_['button_save']             = 'Save';
$_['button_cancel']           = 'Cancel';
$_['button_close']            = 'Close';
$_['button_filter']           = 'Filter';
$_['button_send']             = 'Send';
$_['button_back']             = 'Back';
$_['button_remove']           = 'Remove';
$_['button_backup']           = 'Backup';
$_['button_restore']          = 'Restore';
$_['button_invoice']          = 'Invoice';
$_['button_add_option']       = 'Add Option';
$_['button_add_option_value'] = 'Add Option Value';
$_['button_add_discount']     = 'Add Discount';
$_['button_add_special']      = 'Add Special Price';
$_['button_add_image']        = 'Add Image';
$_['button_add_geo_zone']     = 'Add Geo Zone';
$_['button_add_rate']         = 'Add Tax Rate';

// Tab
$_['tab_admin']               = 'Admin';
$_['tab_cache']               = 'Cache';
$_['tab_data']                = 'Data';
$_['tab_discount']            = 'Discount';
$_['tab_general']             = 'General';
$_['tab_image']               = 'Image';
$_['tab_option']              = 'Option';
$_['tab_server']              = 'Server';
$_['tab_shop']                = 'Shop';
$_['tab_local']               = 'Local';
$_['tab_stats']               = 'Statistics';
$_['tab_order']               = 'Orders';
$_['tab_customer']            = 'Customers';
$_['tab_mail']                = 'Mail';

// Error
$_['error_upload_1']          = 'Warning: The uploaded file exceeds the upload_max_filesize directive in php.ini!';
$_['error_upload_2']          = 'Warning: The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form!';
$_['error_upload_3']          = 'Warning: The uploaded file was only partially uploaded!';
$_['error_upload_4']          = 'Warning: No file was uploaded!';
$_['error_upload_6']          = 'Warning: Missing a temporary folder!';
$_['error_upload_7']          = 'Warning: Failed to write file to disk!';
$_['error_upload_8']          = 'Warning: File upload stopped by extension!';
$_['error_upload_999']        = 'Warning: No error code avaiable!';
?>
